@@ -5,7 +5,7 @@
 
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 2.1 of the License, or
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
@@ -13,27 +13,16 @@
 #define FQ_POLY_FACTOR_H
 
 #ifdef FQ_POLY_FACTOR_INLINES_C
-#define FQ_POLY_FACTOR_TEMPLATES_INLINE FLINT_DLL
-#define FQ_POLY_FACTOR_INLINE FLINT_DLL
+#define FQ_POLY_FACTOR_TEMPLATES_INLINE
+#define FQ_POLY_FACTOR_INLINE
 #else
-#define FQ_POLY_FACTOR_TEMPLATES_INLINE static __inline__
-#define FQ_POLY_FACTOR_INLINE static __inline__
+#define FQ_POLY_FACTOR_TEMPLATES_INLINE static inline
+#define FQ_POLY_FACTOR_INLINE static inline
 #endif
 
-FQ_POLY_FACTOR_INLINE
-int FQ_POLY_ITERATED_FROBENIUS_CUTOFF(const fq_ctx_t ctx, slong length)
-{
-    int result;
-    fmpz_t q;
-    fmpz_init(q);
-    fq_ctx_order(q, ctx);
-    if ( fmpz_sizeinbase(q, 2) < 3 * (n_sqrt(length) + 1))
-        result = 1;
-    else
-        result = 0;
-    fmpz_clear(q);
-    return result;
-}
+#include "fq_types.h"
+
+int FQ_POLY_ITERATED_FROBENIUS_CUTOFF(const fq_ctx_t ctx, slong length);
 
 #ifdef T
 #undef T
@@ -47,7 +36,7 @@ int FQ_POLY_ITERATED_FROBENIUS_CUTOFF(const fq_ctx_t ctx, slong length)
 
 /* Inlines *******************************************************************/
 
-FLINT_DLL void fq_poly_factor_get_poly(fq_poly_t z,
+void fq_poly_factor_get_poly(fq_poly_t z,
 		      const fq_poly_factor_t fac, slong i, const fq_ctx_t ctx);
 
 #endif
